Class: Sis::Core::ApplicationDocumentUploader

Inherits:
CarrierWave::Uploader::Base
  • Object
show all
Defined in:
app/uploaders/sis/core/application_document_uploader.rb

Instance Method Summary collapse

Instance Method Details

#extension_whitelistObject

Add a white list of extensions which are allowed to be uploaded. For images you might use something like this:



40
41
42
# File 'app/uploaders/sis/core/application_document_uploader.rb', line 40

def extension_whitelist
  %w[pdf]
end

#store_dirObject

Override the directory where uploaded files will be stored. This is a sensible default for uploaders that are meant to be mounted:



14
15
16
# File 'app/uploaders/sis/core/application_document_uploader.rb', line 14

def store_dir
  ENV.fetch('UPLOAD_PREFIX') + "uploads/#{model.class.to_s.underscore}/#{mounted_as}/#{model.id}"
end